import greenfoot.*;

/**
 * A Ammo that can hit Jet2s.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 */
public class Ammo extends SmoothMover
{
    /** The damage this Ammo will deal */
    private static final int damage = 16;
    
    /** A Ammo looses one life each act, and will disappear when life = 0 */
    private int life = 30;
    
    /**
     * Default constructor for testing.
     */
    public Ammo()
    {
    }
    
    /**
     * Create a Ammo with given speed and direction of movement.
     */
    public Ammo(Vector speed, int rotation)
    {
        super(speed);
        setRotation(rotation);
        addToVelocity(new Vector(rotation, 15));
        Greenfoot.playSound("EnergyGun.wav");
    }
    
    /**
     * The Ammo will damage Jet2s if it hits them.
     */
    public void act()
    {
        if(life <= 0) {
            getWorld().removeObject(this);
        } 
        else {
            life--;
            move();
            checkJet2Hit();
        }
    }
    
    /**
     * Check whether we have hit an Jet2.
     */
    private void checkJet2Hit()
    {
        Jet2 Jet2 = (Jet2) getOneIntersectingObject(Jet2.class);
        if (Jet2 != null)
        {
            getWorld().removeObject(this);
            Jet2.hit(damage);
        }
    }
}