import greenfoot.*;

/**
 * A rocket that can be controlled by the arrowkeys: up, left, right.
 * The gun is fired by hitting the 'Sky' key. 'z' releases a proton wave.
 * 
 * @author Poul Henriksen
 * @author Michael Kölling
 * 
 * @version 1.1
 */
public class Jet1 extends SmoothMover
{
    private static final int gunReloadTime = 5;         // The minimum delay between firing the gun.

    private int reloadDelayCount;               // How long ago we fired the gun the last time.
    private int protonDelayCount;

    private GreenfootImage rocket = new GreenfootImage("jet1.png");    
    private GreenfootImage rocketWithThrust = new GreenfootImage("jet1.png");

    /**
     * Initialise this rocket.
     */
    public Jet1()
    {
        reloadDelayCount = 5;
        protonDelayCount = 500;
        addToVelocity(new Vector(13, 0.9));
    }


    /**
     * Do what a rocket's gotta do. (Which is: mostly flying about, and turning,
     * accelerating and shooting when the right keys are pressed.)
     */
    public void act()
    {
        checkKeys();
        reloadDelayCount++;
        move();
        checkCollision();
    }

    /**
     * Check whether there are any key pressed and react to them.
     */
    private void checkKeys() 
    {
        ignite(Greenfoot.isKeyDown("up"));
        if (Greenfoot.isKeyDown("Space")) // key used to fire a Ammo
        {
            fire();
        }
        if (Greenfoot.isKeyDown("left"))
        {
            turn(-5);
        }
        if (Greenfoot.isKeyDown("right"))
        {
            turn(5);
        }
    }

    /**
     * Fire a Ammo if the gun is ready.
     */
    private void fire() 
    {
        if (reloadDelayCount >= gunReloadTime) 
        {
            Ammo Ammo = new Ammo (getVelocity(), getRotation());
            getWorld().addObject (Ammo, getX(), getY());
            Ammo.move ();
            reloadDelayCount = 0;
        }
    }

    private void ignite(boolean boosterOn)
    {
        if (boosterOn)
        {
            setImage(rocket);
            addToVelocity(new Vector(getRotation(), 0.3));

        }
    }
    
    private void checkCollision()
    {
        Jet2 a = (Jet2) getOneIntersectingObject(Jet2.class);
        if (a != null)
        { 
            Sky Sky = (Sky) getWorld();
            Sky.addObject(new Explosion(), getX(), getY());
            Sky.removeObject(this);
            Sky.gameOver();
        }
    }

}